@@ -19,7 +19,10 @@ class AuditLog:
             dict: API response containing audit log entries
         """
         path = f"orgs/{org_slug}/audit-log"
-        response = self.api.do_request(path=path, params=kwargs)
+        if kwargs:
+            from urllib.parse import urlencode
+            path += "?" + urlencode(kwargs)
+        response = self.api.do_request(path=path)
         if response.status_code == 200:
             return response.json()
         log.error(f"Error getting audit log: {response.status_code}")
